@@ -3,7 +3,7 @@ package DBIx::Fast;
 use strict;
 use warnings;
 
-our $VERSION = '0.1402';
+our $VERSION = '0.1403';
 
 use Carp;
 use Moo;
@@ -568,7 +568,7 @@ sub Exception {
 
   $out .= " - Last error: ".$self->last_error if $self->last_error;
 
-  carp $out;
+  croak $out;
 }
 
 1;
